### sim_sensors

This is a small python package. It holds two classes - HumiditySensor and TempSensor. There is an additional third
package that provides a function for getting soil humidity values. 
These classes and function simulate simple environmental sensors like those that you would use in an IoT / SmartHome setup.
All constructor parameters are optional. Check the code or docs to see the defaults.